@@ -78,7 +78,10 @@ class Client:
             headers = {'Authorization': 'Token {}'.format(self.api_token)}
             providers = requests.get(url, headers=headers)
             if providers.status_code == 200:
-                return(pd.DataFrame(providers.json()))
+                providers = pd.DataFrame(providers.json())
+                providers['id'] = providers['id'].astype('int')
+                providers['status'] = providers['status'].map({'m':'Maintenance','a':'Active','e':'Expired'})
+                return(providers)
             else:
                 raise RuntimeError("Error {} - {}:  {}".format(providers.status_code, providers.reason, json.loads(providers.content)))
                 
